import mysql from 'mysql2/promise';
import dotenv from 'dotenv';

dotenv.config();

const dbConfig = {
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.DB_DATABASE
};

const pool = mysql.createPool(dbConfig);

export async function checkIfEmailProcessed(emailId) {
    const query = `SELECT COUNT(*) AS count FROM buchungen WHERE email_id = ?`;
    const [rows] = await pool.query(query, [emailId]);
    return rows[0].count > 0;
}

export async function insertOrUpdateBooking(emailData) {
    const query = `
        INSERT INTO buchungen (email_id, buchungs_status, vorname, nachname, adresse, plz, ort, geburtsdatum, telefonnummer, emailadresse, firmenname, anzahl_personen, anzahl_zimmer, einzelpreis, gesamtpreis, zimmernummer, buchungs_kommentare, email_antwort, eingecheckt_erledigt, ai_comment)
        VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
        ON DUPLICATE KEY UPDATE buchungs_status=VALUES(buchungs_status), vorname=VALUES(vorname), nachname=VALUES(nachname), adresse=VALUES(adresse), plz=VALUES(plz), ort=VALUES(ort), geburtsdatum=VALUES(geburtsdatum), telefonnummer=VALUES(telefonnummer), emailadresse=VALUES(emailadresse), firmenname=VALUES(firmenname), anzahl_personen=VALUES(anzahl_personen), anzahl_zimmer=VALUES(anzahl_zimmer), einzelpreis=VALUES(einzelpreis), gesamtpreis=VALUES(gesamtpreis), zimmernummer=VALUES(zimmernummer), buchungs_kommentare=VALUES(buchungs_kommentare), email_antwort=VALUES(email_antwort), eingecheckt_erledigt=VALUES(eingecheckt_erledigt), ai_comment=VALUES(ai_comment)
    `;

    const values = [
        emailData.email_id,
        emailData.buchungs_status,
        emailData.vorname,
        emailData.nachname,
        emailData.adresse,
        emailData.plz,
        emailData.ort,
        emailData.geburtsdatum,
        emailData.telefonnummer,
        emailData.emailadresse,
        emailData.firmenname,
        emailData.anzahl_personen,
        emailData.anzahl_zimmer,
        emailData.einzelpreis,
        emailData.gesamtpreis,
        emailData.zimmernummer,
        emailData.buchungs_kommentare,
        emailData.email_antwort,
        emailData.eingecheckt_erledigt,
        emailData.ai_comment
    ];

    const [result] = await pool.query(query, values);

    if (result.affectedRows === 0) {
        throw new Error('Keine gültigen Daten erhalten');
    }
    return result;
}
