import OpenAI from 'openai';
import chalk from 'chalk';

const openai = new OpenAI({
  apiKey: process.env.OPENAI_API_KEY
});

function sleep(ms) {
  return new Promise(resolve => setTimeout(resolve, ms));
}

async function sendToOpenAI(prompt, model = 'gpt-3.5-turbo') {
  try {
    const chatCompletion = await openai.chat.completions.create({
      messages: [{ role: 'system', content: prompt }],
      model
    });
    return chatCompletion.choices[0].message.content.trim();
  } catch (error) {
    if (error.code === 'rate_limit_exceeded') {
      const retryAfter = error.headers['retry-after-ms'] || 1000;
      console.error(chalk.red(`Rate limit exceeded, retrying after ${retryAfter} ms`));
      await sleep(retryAfter);
      return sendToOpenAI(prompt, model);
    } else if (error.message.includes('context length')) {
      console.error(chalk.red(`Context length exceeded, switching to model gpt-4`));
      return sendToOpenAI(prompt, 'gpt-4');
    } else {
      console.error(chalk.red('Error sending request to OpenAI:', error));
      throw error;
    }
  }
}

export { sendToOpenAI };
